# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel


class Status(BaseModel):
    status_code: Optional[int] = None
    message: Optional[str] = None


class Error(BaseModel):
    status: Optional[Status] = None
