# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from typing import List

from pydantic import BaseModel, Field


class ChampionInfo(BaseModel):
    max_new_player_level: int = Field(..., alias="maxNewPlayerLevel")
    free_champion_ids_for_new_players: List[int] = Field(
        ..., alias="freeChampionIdsForNewPlayers"
    )
    free_champion_ids: List[int] = Field(..., alias="freeChampionIds")
