from enum import Enum


class Region(Enum):
    """# Region to execute against"""

    BR = "br1"
    EUNE = "eun1"
    EUW = "euw1"
    JP = "JP1"
    KR = "kr"
    LAN = "la1"
    LAS = "la2"
    ME = "me1"
    NA = "na1"
    OCE = "oc1"
    RU = "ru1"
    TR = "tr1"
    PH = "ph2"
    SG = "sg2"
    TH = "th2"
    TW = "tw2"
    VN = "vn2"
