# generated by datamodel-codegen:
#   filename:  schema.json
#   timestamp: 2025-10-09T19:10:06+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Field


class AccountDto(BaseModel):
    puuid: str = Field(
        ..., description="Encrypted PUUID. Exact length of 78 characters."
    )
    game_name: Optional[str] = Field(
        None,
        alias="gameName",
        description="This field may be excluded from the response if the account doesn't have a gameName.",
    )
    tag_line: Optional[str] = Field(
        None,
        alias="tagLine",
        description="This field may be excluded from the response if the account doesn't have a tagLine.",
    )


class AccountRegionDTO(BaseModel):
    puuid: str = Field(
        ...,
        description="Player Universal Unique Identifier. Exact length of 78 characters. (Encrypted)",
    )
    game: str = Field(..., description="Game to lookup active region")
    region: str = Field(..., description="Player active region")


class ActiveShardDto(BaseModel):
    puuid: str
    game: str
    active_shard: str = Field(..., alias="activeShard")
